@@ -443,7 +443,7 @@ class Base(Controller):
         ]
     )
     def fd(self):
-        from ..ext.faker import generate_fake_data
+        from ..ext.fake_data import generate_fake_data
         n_lines = int(self.app.pargs.__dict__.get('n') or 10)
         template = self.app.pargs.__dict__.get('t') or self.app.pargs.__dict__.get('template')
         columns = not (self.app.pargs.__dict__.get('c') or self.app.pargs.__dict__.get('columns')) 
@@ -791,7 +791,7 @@ class Base(Controller):
                 "action": "store"
             }),
             (['-p'],{
-                "help" : "Project id. Daily is 0",
+                "help" : "Project name. If not given, grabs IDG.",
                 "action" : 'store'
             }),
             (['-i'],{
@@ -811,7 +811,7 @@ class Base(Controller):
     def td(self):
         from ..ext.asana import add_todo, asana_list_todos, done_todo,  \
             fix_past_due, asana_list_workspaces
-        project = self.app.pargs.p or "Daily"
+        project = self.app.pargs.p or "IDG"
 
         if self.app.pargs.action=='add':
             add_todo(self.app.pargs.t, self.app.pargs.l, self.app.pargs.ws, project)
