@@ -78,7 +78,7 @@ def get_config():
     with open(os.path.expanduser('~/.dt_config.json')) as f:
         # before loading strip all lines starting with // after leading whitespace is stripped
         f = '\n'.join([line for line in f.read().splitlines() if not line.strip().startswith('//')])
-        config = json.loads(f)
+        config = dict(json.loads(f))
     return config
 
 def get_client(oauth=False):
@@ -113,10 +113,10 @@ def get_client(oauth=False):
     return client
 
 
-def asana_list_todos(workspace_name,filtering):
+def asana_list_todos(project_name,filtering):
     if filtering is None: filtering = 'due'
     
-    df = asana_get_todos(workspace_name,filtering)
+    df = asana_get_todos(project_name,filtering)
     df = df[['gid','name',"due_on", "completed", "notes", "subtasks"]] # projects
     
     # get all subtasks
@@ -149,7 +149,7 @@ def asana_list_workspaces(filtering):
     print(workspaces_df)
     
     
-def asana_get_todos(workspace_name,filtering):
+def asana_get_todos(project_name,filtering):
      # read api key from ~/.dt_config.json
     client = get_client(True)
     (url, state) = client.session.authorization_url()
@@ -174,6 +174,11 @@ def asana_get_todos(workspace_name,filtering):
     
 def add_todo(task_text, expected_duration, workspace_id, project_name):
     tm = time.localtime()
+    config = get_config()
+    if 'asana_projects' in config:
+        asana_projects = config['asana_projects']
+    else: asana_projects = None
+    asana_projects = asana_projects if asana_projects is not None else {}
     
     if expected_duration is None:
         tar_date = f"{tm.tm_year}-{tm.tm_mon:02d}-{tm.tm_mday+1:02d}"
@@ -188,14 +193,21 @@ def add_todo(task_text, expected_duration, workspace_id, project_name):
     if workspace_id is None: workspace_id = me['workspaces'][0]['gid']
     
     
-    projects = list(client.projects.get_projects_for_workspace(workspace_id))
-    if project_name == 0:
-        # here project_name is id
-        project_id = projects[int(project_name)]['gid']
+    if project_name not in asana_projects.keys():
+        projects = list(client.projects.get_projects_for_workspace(workspace_id))
+        if project_name == 0:
+            # here project_name is id
+            project_id = projects[int(project_name)]['gid']
+        else:
+            try:
+                project_id = [ w['gid'] for w in projects if w['name'] == project_name][0]
+                print(f"project_id of project name {project_name}: {project_id}")
+            except IndexError:
+                print(f"Project {project_name} not found. But this could also be a bug.")
     else:
-        project_name = 'Daily'
-        project_id = [ w['gid'] for w in projects if w['name'] == project_name][0]
+        project_id = asana_projects[project_name]
         
+            
     # docs https://developers.asana.com/docs/create-a-task
         
     data =  {'name': task_text,
@@ -221,8 +233,8 @@ def done_todo(task_id):
     result = client.tasks.update_task(task_id, data)
     print(json.dumps(result, indent=4))
 
-def fix_past_due(workspace_name):
-    df = asana_get_todos(workspace_name,None)
+def fix_past_due(project_name):
+    df = asana_get_todos(project_name,None)
     client = get_client(True)
     
     # select all that are past due
